{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Literate Curry.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/literate-curry.xml and 'make bootstrap'.
module Skylighting.Syntax.LiterateCurry (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Literate Curry.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2literate-curry.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLiterateCurry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\{-[^#]\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmultiline\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCurry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL>\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCode\NUL<\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCode\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\begin{code}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anormals\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\begin{spec}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anormals\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alineend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alineend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL>\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestart\NUL<\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmultiline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmultiline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH-}\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alineend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anormals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anormals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\end{code}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\end{spec}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCurry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLiterate Curry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH-}\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.Bj\195\182rn Peem\195\182ller (bjp@informatik.uni-kiel.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b*.lcurry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTText"
